library(psych) # useful for summary stats
library(kableExtra) # creates nice tables
library(dplyr) #for data manipulation
library(survival)


df <- read.csv("D:/COURSES I HAVE RUN/Survival Analysis NCRM/copilot propodds dataset/sa_exercise.csv")
head(df)


# Table of data
df %>%
  kbl() %>%
  kable_styling()

###
describe(df[ ,c("ses", "male", "time", "censor", "timedis")], fast=TRUE )


#variable for event is not there, but needs to be created using censor 
#event took place if case is not censored
df$event <- ifelse(df$censor == 1, 0, 1)
table (df$event, df$censor)

####***************************************************************
####***************************************************************
### Life Table ####
####***************************************************************


# Create a survival object
surv_obj <- Surv(time = df$timedis, event = df$event)
surv_obj[1:15]

# Generate the information for the life table
lti <- survfit(surv_obj ~ 1, data = df)


# Calculate the hazard function --> n of events/ n in risk set
hazard_function <- lti$n.event / lti$n.risk

# Combine the results into a data frame
lt <- data.frame(
  time = lti$time,
  n.risk = lti$n.risk,
  n.event = lti$n.event,
  n.censor = lti$n.censor,
  survival = round(lti$surv, 3),
  hazard = round(hazard_function, 3)
)

# Display the life table with hazard function
# Create the table
lt %>%
  kbl() %>%
  kable_classic_2(full_width = F)


#load more librararies
library(ggplot2) # to create plots
library("ggthemes") # used to create plots with preset colours

####***************************************************************
####***************************************************************
### Hazard function plot ####
####***************************************************************


# Plot the discrete time hazard function with color palette
plot_dth<-ggplot(lt, aes(x = time, y = hazard)) +
  geom_line(linewidth=3, col="brown") +
  labs(title = "Discrete Time Hazard Function",
       x = "Time",
       y = "Hazard Function") +
  ylim(c(0,.5)) +
  theme_economist() +  
  scale_x_continuous(breaks = seq(1, 6, by = 1)) #changes the ticks in x axis

plot_dth 


####***************************************************************
####***************************************************************
### Plot the Survival Function ####
####***************************************************************


# Plot the survivor function
plot_surf<-ggplot(lt, aes(x = time, y = survival)) +
  ylim(c(0,1)) +
  geom_line(linewidth=3, col="brown") +
   labs(title = "Survivor Function", x = "Time", y = "Survival Probability") +
  theme_economist() +  
  scale_x_continuous(breaks = seq(1, 6, by = 1)) #changes the ticks in x axis

plot_surf


####***************************************************************
####***************************************************************
### Median Lifetime ####
####***************************************************************


# Extract survival probabilities and times
surv_probs <- summary(lti)$surv
surv_times <- summary(lti)$time

# Find the time points around the median survival probability (0.5)
lower_index <- max(which(surv_probs >= 0.5))
upper_index <- min(which(surv_probs < 0.5))

# Linear interpolation to find the median lifetime
median_lifetime <- surv_times[lower_index] + 
  ((surv_probs[lower_index]-.5)  /
  (surv_probs[lower_index] - surv_probs[upper_index]))

# Print the median lifetime
print(median_lifetime)


####***************************************************************
####***************************************************************
### Add the Median Lifetime to Plot of the Survival Function ####
####***************************************************************



plot_surf2<-plot_surf+geom_vline(xintercept = median_lifetime, linetype = "dashed", color = "navy") +
  annotate("text", x = median_lifetime, y = 0.5, 
           label = paste("Median Lifetime: 2.69"), vjust = -6, color = "navy") 


####***************************************************************
####***************************************************************
### Combine the plots in one figure ####
####***************************************************************
  
library(ggpubr) #to combine plots 
figure <- ggarrange(plot_dth, plot_surf2, 
                    ncol = 2)
figure
